@@ -1,5 +1,12 @@
-__version__ = '0.2.3'
+__version__ = "0.3.0"
 
 from pydicom_seg import template
 from pydicom_seg.reader import MultiClassReader, SegmentReader
 from pydicom_seg.writer import MultiClassWriter
+
+__all__ = [
+    "MultiClassReader",
+    "MultiClassWriter",
+    "SegmentReader",
+    "template",
+]
